==> dcl-5.2C.tar.gz: dcl-5.2C/src/grph2/umpack/umqfnm.c <==
/* umqfnm.f -- translated by f2c (version 19990503).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "f2c.h"

/* Table of constant values */

static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int umqfnm_(char *cpara, char *cfname, ftnlen cpara_len, 
	ftnlen cfname_len)
{
    /* Builtin functions */
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);

    /* Local variables */
    static integer n;
    extern /* Subroutine */ int glcget_(char *, char *, ftnlen, ftnlen), 
	    cfsrch_(char *, integer *, char *, integer *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static char cflist[80*3];
    extern /* Subroutine */ int clower_(char *, ftnlen);
    static char cplist[80*3];
    extern /* Subroutine */ int cupper_(char *, ftnlen);

    s_copy(cplist, " ", (ftnlen)80, (ftnlen)1);
    glcget_("DUPATH", cplist + 80, (ftnlen)6, (ftnlen)80);
    glcget_("DSPATH", cplist + 160, (ftnlen)6, (ftnlen)80);
    for (n = 1; n <= 3; ++n) {
	s_copy(cflist + (n - 1) * 80, cpara, (ftnlen)80, cpara_len);
/* L10: */
    }
    clower_(cflist + 80, (ftnlen)80);
    cupper_(cflist + 160, (ftnlen)80);
    cfsrch_(cplist, &c__3, cflist, &c__3, cfname, (ftnlen)80, (ftnlen)80, 
	    cfname_len);
    return 0;
} /* umqfnm_ */

==> dcl-6.5.2-C.tar.gz: dcl-6.5.2-C/src/grph2/umpack/umqfnm.c <==
/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int umqfnm_(char *cpara, char *cfname, ftnlen cpara_len, 
	ftnlen cfname_len)
{
    /* Builtin functions */
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);

    /* Local variables */
    static integer n;
    extern /* Subroutine */ int glcget_(char *, char *, ftnlen, ftnlen), 
	    cfsrch_(char *, integer *, char *, integer *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static char cflist[80*3];
    extern /* Subroutine */ int clower_(char *, ftnlen);
    static char cplist[80*3];
    extern /* Subroutine */ int cupper_(char *, ftnlen);

    s_copy(cplist, " ", (ftnlen)80, (ftnlen)1);
    glcget_("DUPATH", cplist + 80, (ftnlen)6, (ftnlen)80);
    glcget_("DSPATH", cplist + 160, (ftnlen)6, (ftnlen)80);
    for (n = 1; n <= 3; ++n) {
	s_copy(cflist + (n - 1) * 80, cpara, (ftnlen)80, cpara_len);
/* L10: */
    }
    clower_(cflist + 80, (ftnlen)80);
    cupper_(cflist + 160, (ftnlen)80);
    cfsrch_(cplist, &c__3, cflist, &c__3, cfname, (ftnlen)80, (ftnlen)80, 
	    cfname_len);
    return 0;
} /* umqfnm_ */
